dm
Optional matrix in which each row corresponds to a mutation. Only mutations located on autosomes should be included. Columns in dm must be labeled and must include:
SP - the subpopulation to which the point mutation has been asssigned.
SP_cnv - the subpopulation to which the CNV (overlapping with the point mutation) has been asssigned (if an CNV is present).
chr - the chromosome on which each point mutation is located;
startpos - the genomic position of each point mutation;
PM - the total ploidy of all alleles at the mutated genomic locus, in the assigned subpopulation.
PM_B - the ploidy of the B-allele at the mutated genomic locus, in the assigned subpopulation.
If dm is available, an attempt will be made to: i) assign total ploidy (PM) to subpopulations with point mutations and ii) assign every mutation to >1 subpopulation according to the inferred phylogenetic relations between subpopulations. Default: NA.