Learn R Programming

expands (version 1.4)

buildPhylo: Relations between subpopulations

Description

Predicts phylogenetic relations between subpopulations from subpopulation specific copy number profiles.

Usage

buildPhylo(ploidy, outF, treeAlgorithm="bionjs")

Arguments

ploidy
Matrix in which each row corrsponds to a copy number segment. Has to contain at least one column for each predicted subpopulation, with columnname labeled SP_xx, where xx is the size of the corresponding SP. Ploidy-matrix can be obtained by calling
outF
Prefix of file to which phylogeny will be saved.
treeAlgorithm
Neighbor joining algorithm used for phylogeny reconstruction (from library ape). Options: bionjs (default), njs.

Value

  • An object of class "phylo" (library ape).

Details

Reconstructs phylogenetic relationships between subpopulations using the BIONJ algorithm of Gascuel. Pairwise distances between subpopulations are calculated as the number of copy number segments for which both subpopulations have the same copy number, divided by the total number of copy number segments for which both subpopulations have available copy number information. Subpopulations with insufficient ploidy information are excluded from phylogeny.

See Also

assignQuantityToSP